@@ -20,7 +20,7 @@ Mostly harmless
 use warnings;
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 METHODS
 
@@ -47,6 +47,10 @@ sub ultimate_answer {
 
 __END__
 
+=head1 SEE ALSO
+
+L<aliased>
+
 =head1 CREDITS
 
 Thanks to Pauline Barmby from University of Western Ontario for helping
